==> gcalctool-5.27.2.tar.bz2: gcalctool-5.27.2/src/mp-equation-parser.h <==

/* A Bison parser, made by GNU Bison 2.4.1.  */

/* Skeleton interface for Bison's Yacc-like parsers in C
   
      Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004, 2005, 2006
   Free Software Foundation, Inc.
   
   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.
   
   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.
   
   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.  */

/* As a special exception, you may create a larger work that contains
   part or all of the Bison parser skeleton and distribute that work
   under terms of your choice, so long as that work isn't itself a
   parser generator using the skeleton or a modified version thereof
   as a parser skeleton.  Alternatively, if you modify or redistribute
   the parser skeleton itself, you may (at your option) remove this
   special exception, which will cause the skeleton and the resulting
   Bison output files to be licensed under the GNU General Public
   License without this special exception.
   
   This special exception was added by the Free Software Foundation in
   version 2.2 of Bison.  */


/* Tokens.  */
#ifndef YYTOKENTYPE
# define YYTOKENTYPE
   /* Put the tokens into the symbol table, so that GDB and other debuggers
      know about them.  */
   enum yytokentype {
     tABS = 258,
     tACOS = 259,
     tACOSH = 260,
     tAND = 261,
     tANS = 262,
     tASIN = 263,
     tASINH = 264,
     tATAN = 265,
     tATANH = 266,
     tCBRT = 267,
     tCHS = 268,
     tCLR = 269,
     tCOS = 270,
     tCOSH = 271,
     tEXP = 272,
     tFRAC = 273,
     tINT = 274,
     tLN = 275,
     tLOG10 = 276,
     tLOG2 = 277,
     tMOD = 278,
     t1S = 279,
     t2S = 280,
     tNOT = 281,
     tOR = 282,
     tPI = 283,
     tRAND = 284,
     tRCL = 285,
     tSIN = 286,
     tSINH = 287,
     tSQRT = 288,
     tSTO = 289,
     tTAN = 290,
     tTANH = 291,
     tTRUNC = 292,
     tXNOR = 293,
     tXOR = 294,
     tNUMBER = 295,
     tREG = 296,
     NEG = 297,
     MED = 298,
     LNEG = 299,
     POS = 300,
     HIGH = 301
   };
#endif



#if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
typedef union YYSTYPE
{

/* Line 1676 of yacc.c  */
#line 41 "./mp-equation-parser.y"

  MPNumber int_t;
  int integer;



/* Line 1676 of yacc.c  */
#line 105 "mp-equation-parser.h"
} YYSTYPE;
# define YYSTYPE_IS_TRIVIAL 1
# define yystype YYSTYPE /* obsolescent; will be withdrawn */
# define YYSTYPE_IS_DECLARED 1
#endif



#if ! defined YYLTYPE && ! defined YYLTYPE_IS_DECLARED
typedef struct YYLTYPE
{
  int first_line;
  int first_column;
  int last_line;
  int last_column;
} YYLTYPE;
# define yyltype YYLTYPE /* obsolescent; will be withdrawn */
# define YYLTYPE_IS_DECLARED 1
# define YYLTYPE_IS_TRIVIAL 1
#endif

==> gcalctool-5.27.3.tar.bz2: gcalctool-5.27.3/src/mp-equation-parser.h <==

/* A Bison parser, made by GNU Bison 2.4.1.  */

/* Skeleton interface for Bison's Yacc-like parsers in C
   
      Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004, 2005, 2006
   Free Software Foundation, Inc.
   
   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.
   
   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.
   
   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.  */

/* As a special exception, you may create a larger work that contains
   part or all of the Bison parser skeleton and distribute that work
   under terms of your choice, so long as that work isn't itself a
   parser generator using the skeleton or a modified version thereof
   as a parser skeleton.  Alternatively, if you modify or redistribute
   the parser skeleton itself, you may (at your option) remove this
   special exception, which will cause the skeleton and the resulting
   Bison output files to be licensed under the GNU General Public
   License without this special exception.
   
   This special exception was added by the Free Software Foundation in
   version 2.2 of Bison.  */


/* Tokens.  */
#ifndef YYTOKENTYPE
# define YYTOKENTYPE
   /* Put the tokens into the symbol table, so that GDB and other debuggers
      know about them.  */
   enum yytokentype {
     tADD = 258,
     tSUBTRACT = 259,
     tMULTIPLY = 260,
     tDIVIDE = 261,
     tABS = 262,
     tABS_FUNC = 263,
     tACOS = 264,
     tACOSH = 265,
     tAND = 266,
     tANS = 267,
     tASIN = 268,
     tASINH = 269,
     tATAN = 270,
     tATANH = 271,
     tCBRT = 272,
     tCHS = 273,
     tCLR = 274,
     tCOS = 275,
     tCOSH = 276,
     tEXP = 277,
     tFRAC = 278,
     tINT = 279,
     tLN = 280,
     tLOG10 = 281,
     tLOG2 = 282,
     tMOD = 283,
     t1S = 284,
     t2S = 285,
     tNOT = 286,
     tOR = 287,
     tPI = 288,
     tRAND = 289,
     tRCL = 290,
     tSIN = 291,
     tSINH = 292,
     tROOT = 293,
     tROOT3 = 294,
     tROOT4 = 295,
     tSQUARED = 296,
     tCUBED = 297,
     tSQRT = 298,
     tSTO = 299,
     tTAN = 300,
     tTANH = 301,
     tTRUNC = 302,
     tXNOR = 303,
     tXOR = 304,
     tNUMBER = 305,
     tREG = 306,
     NEG = 307,
     MED = 308,
     LNEG = 309,
     POS = 310,
     HIGH = 311
   };
#endif



#if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
typedef union YYSTYPE
{

/* Line 1676 of yacc.c  */
#line 41 "./mp-equation-parser.y"

  MPNumber int_t;
  int integer;



/* Line 1676 of yacc.c  */
#line 115 "mp-equation-parser.h"
} YYSTYPE;
# define YYSTYPE_IS_TRIVIAL 1
# define yystype YYSTYPE /* obsolescent; will be withdrawn */
# define YYSTYPE_IS_DECLARED 1
#endif



#if ! defined YYLTYPE && ! defined YYLTYPE_IS_DECLARED
typedef struct YYLTYPE
{
  int first_line;
  int first_column;
  int last_line;
  int last_column;
} YYLTYPE;
# define yyltype YYLTYPE /* obsolescent; will be withdrawn */
# define YYLTYPE_IS_DECLARED 1
# define YYLTYPE_IS_TRIVIAL 1
#endif
